# rili

一个带农历和节日的终端日历应用，基于 [Textual](https://github.com/Textualize/textual)。

## 方法一: 采用 x-cmd

```
x rili
```

## 方法二: 安装

```bash
pip install x-cmd-rili
```

## 使用

```bash
rili
```

## 依赖
- textual
- cnlunar
- rich

## 许可证
MIT